@@ -36,8 +36,9 @@ class Utils(object):
 	#SKEN_SERVER_BASE_URL = 'http://localhost:8080/api/cli/v1'
 	http = None
 	last_time_docker_login = 0
-	minutes25 = 60*25
+	minutes20 = 60*20
 	cloc_file = None
+	cloc_data = None
 	min_docker_version = 18.03
 	# if a scanner for an app id is executed too close in time, skencli must wait for 5 minutes
 	etl_waiting_threshold = 300
@@ -45,6 +46,7 @@ class Utils(object):
 	container_exit_code_kill = 137
 	# retrying upload to s3
 	upload_retry = False
+	docker_auth_config = None
 
 	@classmethod
 	def get_retryable_http(cls):
@@ -93,9 +95,9 @@ class Utils(object):
 
 	@classmethod
 	def docker_login(cls, scan_info):
-		# no need to login again within 30 minutes
+		# no need to login again within 20 minutes
 		now = cls.get_timestamp()
-		if (now - cls.last_time_docker_login) < cls.minutes25:
+		if (now - cls.last_time_docker_login) < cls.minutes20:
 			return docker.from_env()
 
 		print('Logging in to docker')
@@ -112,7 +114,9 @@ class Utils(object):
 		except Exception as e:
 			raise DockerError('Login to docker failed while getting ECR authorization token: ' + str(e), None)
 
-		command = ['docker', 'login', '-u', ecr_username, '--password-stdin', registry]
+		cls.docker_auth_config = {'username': ecr_username, 'password': ecr_password}
+
+		"""command = ['docker', 'login', '-u', ecr_username, '--password-stdin', registry]
 		if sys.version_info < (3, 0):
 			command = ['docker login -u ' + ecr_username + ' --password-stdin ' + registry]
 
@@ -128,14 +132,13 @@ class Utils(object):
 		client = docker.from_env()
 		cls.last_time_docker_login = cls.get_timestamp()
 		"""
-		below code doesn't work even it returns 'Login succeeded', see https://github.com/docker/docker-py/issues/2256
+		cls.last_time_docker_login = cls.get_timestamp()
 		client = docker.from_env()
 		try:
-			client.login(username=ecr_username, password=ecr_password, registry=registry, reauth=False)
+			client.login(username=ecr_username, password=ecr_password, registry=registry)
+			print('Login to docker succeeded.')
 		except Exception as e:
-			print('Failed to login to docker: ' + str(e))
-			exit(-1)
-		"""
+			raise DockerError('Login to docker failed: ' + str(e), None)
 
 		return client
 
@@ -154,7 +157,7 @@ class Utils(object):
 		p.wait()
 		"""
 		try:
-			docker_client.images.pull(image)
+			docker_client.images.pull(image, auth_config=cls.docker_auth_config)
 		except Exception as e:
 			# pull failed, check if the image exists, if true then use the current version, otherwise raise error
 			try:
@@ -266,9 +269,12 @@ class Utils(object):
 
 			with open(cls.cloc_file, 'r') as f:
 				data = json.load(f)
+				cls.cloc_data = data
 				if 'SUM' in data:
 					files = data['SUM']['nFiles']
 					lines_of_code = data['SUM']['code']
+			
+			os.remove(cls.cloc_file)
 		except Exception as e:
 			print('Failed to count files and lines of code: ' + str(e))
 			
@@ -451,14 +457,18 @@ class Utils(object):
 			output_file_handle = open(output_file, 'rb')
 			s3.Bucket('sken-scanner-output').put_object(Key=app_id + '/' + scan_id + '/' + file_name, Body=output_file_handle)
 
-			# upload cloc file
-			try:
-				if cls.cloc_file is not None and os.path.exists(cls.cloc_file):
-					cloc_file_handle = open(cls.cloc_file, 'rb')
-					s3.Bucket('sken-scanner-output').put_object(Key=app_id + '/' + scan_id + '/sken-cloc.json', Body=cloc_file_handle)
-			except Exception as ce:
-				# ignore
-				cls.noop()
+			if cls.cloc_data is not None:
+				with open(cls.cloc_file, 'w') as f:
+					f.write(json.dumps(cls.cloc_data))
+				# upload cloc file
+				try:
+					if cls.cloc_file is not None and os.path.exists(cls.cloc_file):
+						cloc_file_handle = open(cls.cloc_file, 'rb')
+						s3.Bucket('sken-scanner-output').put_object(Key=app_id + '/' + scan_id + '/sken-cloc.json', Body=cloc_file_handle)
+						cls.cloc_data = None
+				except Exception as ce:
+					# ignore
+					cls.noop()
 		
 			print('Output file uploaded')
 		except Exception as e:
